#!/bin/bash

echo "Installing Docker and Docker Compose on Ubuntu..."

# Step 1: Remove older Docker versions (if any)
sudo apt remove -y docker docker-engine docker.io containerd runc

# Step 2: Update package index
sudo apt update

# Step 3: Install dependencies
sudo apt install -y \
    ca-certificates \
    curl \
    gnupg \
    lsb-release \
    apt-transport-https \
    software-properties-common

# Step 4: Add Docker’s official GPG key
sudo mkdir -p /etc/apt/keyrings
curl -fsSL https://download.docker.com/linux/ubuntu/gpg | \
    sudo gpg --dearmor -o /etc/apt/keyrings/docker.gpg

# Step 5: Set up Docker repository
echo \
  "deb [arch=$(dpkg --print-architecture) \
  signed-by=/etc/apt/keyrings/docker.gpg] \
  https://download.docker.com/linux/ubuntu \
  $(lsb_release -cs) stable" | \
  sudo tee /etc/apt/sources.list.d/docker.list > /dev/null

# Step 6: Update and install Docker
sudo apt update
sudo apt install -y docker-ce docker-ce-cli containerd.io docker-buildx-plugin docker-compose-plugin

# Step 7: Enable and start Docker
sudo systemctl enable docker
sudo systemctl start docker

# Step 8: (Optional) Add current user to docker group (to avoid needing sudo)
if ! groups $USER | grep -q docker; then
    echo " Adding $USER to docker group..."
    sudo usermod -aG docker $USER
    echo "⚠ Please log out and back in for group changes to take effect."
fi

# Step 9: Test
echo " Docker installed. Testing..."
docker --version
docker compose version

echo " Done!"
