#!/bin/bash

echo "Starting manual setup for OpenVAS dashboard..."

# Ensure we're running on Ubuntu with sudo
if [[ $EUID -ne 0 ]]; then
   echo "This script must be run with sudo: sudo ./setup_manual.sh"
   exit 1
fi

# ---- 1. System Dependencies ----
echo "Installing system dependencies..."
apt update && apt install -y \
    nmap \
    python3 \
    python3-pip \
    python3-venv \
    libxslt1-dev \
    libxml2-dev \
    libffi-dev \
    build-essential \
    virtualenv \
    unzip \
    net-tools \
    curl

# ---- 2. Python Virtual Environment ----
PROJECT_DIR=$(pwd)
echo "Creating virtual environment in: $PROJECT_DIR/venv"
python3 -m venv venv
source venv/bin/activate

# ---- 3. Install Python Packages ----
echo "Installing Python dependencies in virtual environment..."
pip install --upgrade pip
pip install dash dash-bootstrap-components pandas plotly psutil python-nmap lxml tabulate python-dotenv schedule gvm-tools

echo "Manual setup complete!"
echo "To activate your virtual environment later, run:"
echo "source $PROJECT_DIR/venv/bin/activate"


echo ""
echo "To run the scheduler:"
echo " sudo $PROJECT_DIR/venv/bin/python3 $PROJECT_DIR/scheduler.py"

